fract_curve_clust: Decide the number of clusters by the fracture point of the...

Description Usage Arguments

View source: R/fract_curve_clust.R

Description

Decide the number of clusters by the fracture point of the height.

Usage

1
2
3
4
5
6
7
fract_curve_clust(df.features = OTUdata_all,
  df.phenotype = pData(obj.ADS), var.phenoGroup = "Disease",
  method.dist.row = "manhattan", method.dist.col = "manhattan",
  method.hclust.row = "ward", method.hclust.col = "ward",
  method.height = "substr.max", criteria = "max_I.Y",
  fisher_test = TRUE, dir.output = NULL, get.df_of_IYs,
  fn.plot_pdf = NULL, fn.df_of_IYs = NULL)

Arguments

df.features

A data.frame-class object.

df.phenotype

A data.frame-class object.

method.dist.row

A distance metric for clustering of features.

method.dist.col

A distance metric for clustering of samples.

method.hclust.row

An aggromerizing algorithm for clustering of features.

method.hclust.col

An aggromerizing algorithm for clustering of samples.

method.height

'substr.max' (default) or 'direct'.

criteria

Criteria on I.Y for the point to be identified.

dir.output

The directory to output results.

get.df_of_IYs

A logical if IYs will be obtained as data.frame in result.

fn.plot_pdf

The pdf file name for outputs.

fn.df_of_IYs

The csv file name for IY output.


mrmtshmp/FractCurve documentation built on Feb. 5, 2020, 1:13 p.m.