Finding a point of fracture on a Kaplan-Meier curve.
1 2 3 |
data |
A data.frame-class object. |
var.time |
A column name specifies the time variable in the data. |
var.event |
A column name specifies the event variable in the data. |
criteria |
Default = 'max_I.Y'; Criteria on I.Y for the point to be identified. |
fn.plot_pdf |
A character string for thefile name of output image as pdf file. |
km.fit |
As an alternative to "data", "var.time" and "var.event", you can choose input a survfit-class object. |
dir.output |
The directory to output results. |
get.df_of_IYs |
A logical if IYs will be obtained as data.frame in result. |
fn.df_of_IYs |
The csv file name for IY output. |
fn.plot_pdf |
The pdf file name for outputs. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.